module.exports = defineTest({
	description: 'does not remove duplicated var declarations (#716)'
});
